@@ -1,7 +1,11 @@
 import asyncio
 from abstract_apis import get_url,make_endpoint,get_headers,get_async_response
 def getSolcatcherUrl():
-  return 'https://solcatcher.io:5000'
+  return 'http://solcatcher.io'
+def getSolcatcherFlaskUrl():
+  return 'http://solcatcher.io/flask'
+def getSolcatcherTsUrl():
+  return 'http://solcatcher.io/typescript'
 def getEndpointUrl(endpoint=None,url=None):
   url = url or getSolcatcherUrl()
   endpoint = make_endpoint(endpoint or '/')
